{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#Dockstore.cwl",
            "label": "CGP file checksum generator",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/dockstore-cgp-chksum/status)\nA Docker container for producing file md5sum and sha512sum. See the [dockstore-cgp-chksum](https://github.com/cancerit/dockstore-cgp-chksum) website for more information.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/dockstore-cgp-chksum:0.4.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-A",
                        "position": 5
                    },
                    "doc": "Flag to suppress all curl exit status",
                    "id": "#Dockstore.cwl/cgp-chksum/ignore_all_curl_exits"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int",
                            "inputBinding": {
                                "prefix": "-E",
                                "separate": true,
                                "shellQuote": true
                            }
                        }
                    ],
                    "doc": "Optional curl exit codes to suppress",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/ignore_curl_exits"
                },
                {
                    "type": "File",
                    "doc": "file to have checksum generated from",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/in_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "use as chksum output instead of generating a new one.",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-j",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/in_json"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Optional PUT address to send JSON results",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-p",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/put_address"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "prefix": "-H",
                                "separate": true,
                                "shellQuote": true
                            }
                        }
                    ],
                    "doc": "Optional headers to send with JSON results",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/put_headers"
                }
            ],
            "baseCommand": [
                "/opt/wtsi-cgp/bin/sums2json.sh"
            ],
            "http://purl.org/dc/terms/creator": {
                "@id": "yaobo.xu@sanger.ac.uk",
                "foaf:name": "Yaobo Xu",
                "foaf:mbox": "yx2@sanger.ac.uk"
            },
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.in_file.basename).check_sums.json"
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/chksum_json"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.in_file.basename).server_response.txt"
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/server_response"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#Dockstore.cwl_2",
            "label": "CGP sequence validator",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/dockstore-cgp-seqval:1.5.4"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Fastq files to verify, can be gzipped.",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1,
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl_2/cgp-seqval/fastqs_in"
                },
                {
                    "type": "string",
                    "doc": "Not to be overridden by users: Output as interleaved FASTQ (ignored for interleaved input)",
                    "default": "interleaved.fq.gz",
                    "inputBinding": {
                        "prefix": "-o",
                        "position": 3,
                        "separate": true
                    },
                    "id": "#Dockstore.cwl_2/cgp-seqval/output_fq"
                },
                {
                    "type": "int",
                    "doc": "Assess phred quality scale using N pairs (0=all, slow)",
                    "default": 100000,
                    "inputBinding": {
                        "prefix": "-q",
                        "position": 2,
                        "separate": true
                    },
                    "id": "#Dockstore.cwl_2/cgp-seqval/qc_pairs"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "interleaved.fq.gz"
                    },
                    "id": "#Dockstore.cwl_2/cgp-seqval/ifastq_out"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "report.json"
                    },
                    "id": "#Dockstore.cwl_2/cgp-seqval/report_json"
                }
            ],
            "baseCommand": [
                "cgpSeqInputVal",
                "seq-valid",
                "-r",
                "report.json"
            ],
            "doc": "![build_status](https://quay.io/repository/wtsicgp/dockstore-cgp-seqval/status)\nA Docker container for validating interleaved fastq files.\n\nSee the dockstore-cgp-seqval [README](https://github.com/cancerit/dockstore-cgp-seqval/blob/develop/README.md)\nfor full details of how to use.\n",
            "http://schema.org/codeRepository": "https://github.com/cancerit/dockstore-cgp-seqval",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-5634-1539",
                    "http://schema.org/email": "mailto:keiranmraine@gmail.com",
                    "http://schema.org/name": "Keiran Raine"
                }
            ],
            "http://purl.org/dc/terms/creator": {
                "@id": "keiranmraine@gmail.com",
                "foaf:name": "Keiran Raine",
                "foaf:mbox": "keiranmraine@gmail.com"
            }
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "CGP checksum and interleaved fastq generation workflow for a paired fastq",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Gzipped fastq files to import.",
                    "id": "#main/fastq_in"
                },
                {
                    "type": {
                        "type": "array",
                        "items": [
                            "null",
                            "string"
                        ]
                    },
                    "doc": "PUT address to send JSON results of checksums, use list of empty strings if no PUT is required.",
                    "id": "#main/put_address"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "Optional headers to send with JSON results.",
                    "id": "#main/put_headers"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/input_chksum/chksum_json",
                    "id": "#main/chksum_json"
                },
                {
                    "type": {
                        "type": "array",
                        "items": [
                            "null",
                            "File"
                        ]
                    },
                    "outputSource": "#main/input_chksum/server_response",
                    "id": "#main/chksum_put_server_response"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/interleave/ifastq_out",
                    "id": "#main/interleaved_fastq_out"
                },
                {
                    "type": "File",
                    "outputSource": "#main/manifest_string_to_file/outfile",
                    "id": "#main/results_manifest"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "valueFrom": "$(true)",
                            "id": "#main/input_chksum/ignore_all_curl_exits"
                        },
                        {
                            "source": "#main/fastq_in",
                            "id": "#main/input_chksum/in_file"
                        },
                        {
                            "source": "#main/put_address",
                            "id": "#main/input_chksum/put_address"
                        },
                        {
                            "source": "#main/put_headers",
                            "id": "#main/input_chksum/put_headers"
                        }
                    ],
                    "out": [
                        "#main/input_chksum/chksum_json",
                        "#main/input_chksum/server_response"
                    ],
                    "scatter": [
                        "#main/input_chksum/in_file",
                        "#main/input_chksum/put_address"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#Dockstore.cwl",
                    "id": "#main/input_chksum"
                },
                {
                    "in": [
                        {
                            "source": "#main/fastq_in",
                            "id": "#main/interleave/fastqs_in"
                        },
                        {
                            "valueFrom": "$(1)",
                            "id": "#main/interleave/qc_pairs"
                        }
                    ],
                    "out": [
                        "#main/interleave/ifastq_out"
                    ],
                    "run": "#Dockstore.cwl_2",
                    "id": "#main/interleave"
                },
                {
                    "in": [
                        {
                            "source": [
                                "#main/results_manifest_string/out_string"
                            ],
                            "id": "#main/manifest_string_to_file/in_string"
                        }
                    ],
                    "out": [
                        "#main/manifest_string_to_file/outfile"
                    ],
                    "run": "#string_to_file.cwl",
                    "id": "#main/manifest_string_to_file"
                },
                {
                    "in": [
                        {
                            "source": "#main/interleave/ifastq_out",
                            "id": "#main/output_chksum/in_file"
                        }
                    ],
                    "out": [
                        "#main/output_chksum/chksum_json"
                    ],
                    "run": "#Dockstore.cwl",
                    "id": "#main/output_chksum"
                },
                {
                    "in": [
                        {
                            "source": "#main/input_chksum/chksum_json",
                            "id": "#main/results_manifest_string/input_chksum_results"
                        },
                        {
                            "source": "#main/fastq_in",
                            "id": "#main/results_manifest_string/input_files"
                        },
                        {
                            "source": [
                                "#main/output_chksum/chksum_json"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/results_manifest_string/output_chksum_results"
                        },
                        {
                            "source": [
                                "#main/interleave/ifastq_out"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/results_manifest_string/output_files"
                        }
                    ],
                    "out": [
                        "#main/results_manifest_string/out_string"
                    ],
                    "run": "#results_manifest.cwl",
                    "id": "#main/results_manifest_string"
                }
            ],
            "doc": "A workflow to generate checksums of FastQ files and a interleaved FastQ from them. See the [workflow-seq-import](https://github.com/cancerit/workflow-seq-import) website for more information.\n",
            "http://schema.org/codeRepository": "https://github.com/cancerit/workflow-seq-import",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:yyaobo@gmail.com",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ],
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Yaobo Xu",
                "foaf:mbox": "genservhelp@sanger.ac.uk"
            }
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "loadContents": true
                        }
                    },
                    "id": "#results_manifest.cwl/input_chksum_results"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#results_manifest.cwl/input_files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "loadContents": true
                        }
                    },
                    "id": "#results_manifest.cwl/output_chksum_results"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#results_manifest.cwl/output_files"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#results_manifest.cwl/output_rg_info_file"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "id": "#results_manifest.cwl/out_string"
                }
            ],
            "expression": "${\n  function name_and_chksum(files, chksum_out_json_files) {\n    var metas = [];\n    for (var i=0; i<files.length; i++) {\n      var temp_obj = JSON.parse(chksum_out_json_files[i].contents);\n      metas.push({name: files[i].basename, size: files[i].size, md5: temp_obj.md5sum, sha2: temp_obj.sha2sum});\n    }\n    return metas;\n  }\n\n  function name_and_checksum_and_rg(files, chksum_out_json_files, rg_info_file){\n    var metas = [];\n    var rg_obj = JSON.parse(rg_info_file.contents);\n    var rg_dict = {};\n    for(var j=0; j<rg_obj.length; j++){ \n      rg_dict[rg_obj[j][\"ID\"]] = rg_obj[j];   \n    }\n    for (var i=0; i<files.length; i++) {\n      //Use file basename e.g. rg_split_10659_i.fq.gz to get RG ID\n      var rg_id = (files[i].basename).slice(9,-8);\n      var temp_obj = JSON.parse(chksum_out_json_files[i].contents);\n      metas.push({name: files[i].basename, size: files[i].size, md5: temp_obj.md5sum, sha2: temp_obj.sha2sum, rg_info: rg_dict[rg_id]});\n    }\n    return metas;\n  }\n\n  var final_meta;\n  if (inputs.output_rg_info_file) {\n      final_meta = { input: name_and_chksum(inputs.input_files, inputs.input_chksum_results), output: name_and_checksum_and_rg(inputs.output_files, inputs.output_chksum_results, inputs.output_rg_info_file) };\n  } else {\n      final_meta = { input: name_and_chksum(inputs.input_files, inputs.input_chksum_results), output: name_and_chksum(inputs.output_files, inputs.output_chksum_results) };\n  }\n  return {out_string: JSON.stringify(final_meta)} \n}\n",
            "id": "#results_manifest.cwl"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#string_to_file.cwl/in_string"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results_manifest.json"
                    },
                    "id": "#string_to_file.cwl/outfile"
                }
            ],
            "baseCommand": [
                "echo"
            ],
            "stdout": "results_manifest.json",
            "id": "#string_to_file.cwl"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schema.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
